"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_provision_vdb_parameters import BaseProvisionVDBParameters
from delphix.api.gateway.model.tag import Tag
globals()['BaseProvisionVDBParameters'] = BaseProvisionVDBParameters
globals()['Tag'] = Tag
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_parameters import ProvisionVDBGroupFromBookmarkParameters


class TestProvisionVDBGroupFromBookmarkParameters(unittest.TestCase):
    """ProvisionVDBGroupFromBookmarkParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProvisionVDBGroupFromBookmarkParameters(self):
        """Test ProvisionVDBGroupFromBookmarkParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ProvisionVDBGroupFromBookmarkParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from delphix.api.gateway.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from delphix.api.gateway.model.api_classification_config import APIClassificationConfig
from delphix.api.gateway.model.access_group import AccessGroup
from delphix.api.gateway.model.access_group_account_ids_request import AccessGroupAccountIdsRequest
from delphix.api.gateway.model.access_group_scope import AccessGroupScope
from delphix.api.gateway.model.access_group_scopes_request import AccessGroupScopesRequest
from delphix.api.gateway.model.access_group_update_parameters import AccessGroupUpdateParameters
from delphix.api.gateway.model.account import Account
from delphix.api.gateway.model.account_create_parameter import AccountCreateParameter
from delphix.api.gateway.model.account_create_response import AccountCreateResponse
from delphix.api.gateway.model.account_login_parameter import AccountLoginParameter
from delphix.api.gateway.model.account_update_parameter import AccountUpdateParameter
from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
from delphix.api.gateway.model.all_object_permissions_response import AllObjectPermissionsResponse
from delphix.api.gateway.model.always_allowed_permission import AlwaysAllowedPermission
from delphix.api.gateway.model.always_allowed_permission_request import AlwaysAllowedPermissionRequest
from delphix.api.gateway.model.api_classification_object import ApiClassificationObject
from delphix.api.gateway.model.api_usage_data import ApiUsageData
from delphix.api.gateway.model.api_usage_report_response import ApiUsageReportResponse
from delphix.api.gateway.model.base_provision_vdb_parameters import BaseProvisionVDBParameters
from delphix.api.gateway.model.base_provision_vdb_parameters_all_of import BaseProvisionVDBParametersAllOf
from delphix.api.gateway.model.bookmark import Bookmark
from delphix.api.gateway.model.bookmark_create_parameters import BookmarkCreateParameters
from delphix.api.gateway.model.cdb import CDB
from delphix.api.gateway.model.change_password_parameter import ChangePasswordParameter
from delphix.api.gateway.model.connectivity_check_parameters import ConnectivityCheckParameters
from delphix.api.gateway.model.connectivity_check_response import ConnectivityCheckResponse
from delphix.api.gateway.model.connector import Connector
from delphix.api.gateway.model.connector_test_response import ConnectorTestResponse
from delphix.api.gateway.model.connector_update_parameters import ConnectorUpdateParameters
from delphix.api.gateway.model.copy_masking_job_parameters import CopyMaskingJobParameters
from delphix.api.gateway.model.copy_masking_job_response import CopyMaskingJobResponse
from delphix.api.gateway.model.create_bookmark_response import CreateBookmarkResponse
from delphix.api.gateway.model.create_database_template_response import CreateDatabaseTemplateResponse
from delphix.api.gateway.model.create_environment_response import CreateEnvironmentResponse
from delphix.api.gateway.model.create_environment_user_response import CreateEnvironmentUserResponse
from delphix.api.gateway.model.create_host_response import CreateHostResponse
from delphix.api.gateway.model.create_role import CreateRole
from delphix.api.gateway.model.create_vdb_group_request import CreateVDBGroupRequest
from delphix.api.gateway.model.create_vdb_group_response import CreateVDBGroupResponse
from delphix.api.gateway.model.d_source import DSource
from delphix.api.gateway.model.d_source_consumption_data import DSourceConsumptionData
from delphix.api.gateway.model.d_source_consumption_report_response import DSourceConsumptionReportResponse
from delphix.api.gateway.model.d_source_snapshot_parameters import DSourceSnapshotParameters
from delphix.api.gateway.model.d_source_usage_data import DSourceUsageData
from delphix.api.gateway.model.d_source_usage_report_response import DSourceUsageReportResponse
from delphix.api.gateway.model.data_point_by_snapshot_parameters import DataPointBySnapshotParameters
from delphix.api.gateway.model.data_point_by_timestamp_parameters import DataPointByTimestampParameters
from delphix.api.gateway.model.data_point_from_bookmark_parameters import DataPointFromBookmarkParameters
from delphix.api.gateway.model.database_template import DatabaseTemplate
from delphix.api.gateway.model.database_template_create_parameters import DatabaseTemplateCreateParameters
from delphix.api.gateway.model.delete_database_template_response import DeleteDatabaseTemplateResponse
from delphix.api.gateway.model.delete_engine_response import DeleteEngineResponse
from delphix.api.gateway.model.delete_environment_response import DeleteEnvironmentResponse
from delphix.api.gateway.model.delete_environment_user_response import DeleteEnvironmentUserResponse
from delphix.api.gateway.model.delete_host_response import DeleteHostResponse
from delphix.api.gateway.model.delete_masking_job_response import DeleteMaskingJobResponse
from delphix.api.gateway.model.delete_scope_object_tags import DeleteScopeObjectTags
from delphix.api.gateway.model.delete_scoped_object_item import DeleteScopedObjectItem
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.delete_vdb_parameters import DeleteVDBParameters
from delphix.api.gateway.model.delete_vdb_response import DeleteVDBResponse
from delphix.api.gateway.model.disable_environment_response import DisableEnvironmentResponse
from delphix.api.gateway.model.disable_vdb_parameters import DisableVDBParameters
from delphix.api.gateway.model.disable_vdb_response import DisableVDBResponse
from delphix.api.gateway.model.domain import Domain
from delphix.api.gateway.model.effective_scope import EffectiveScope
from delphix.api.gateway.model.enable_environment_response import EnableEnvironmentResponse
from delphix.api.gateway.model.enable_vdb_parameters import EnableVDBParameters
from delphix.api.gateway.model.enable_vdb_response import EnableVDBResponse
from delphix.api.gateway.model.engine import Engine
from delphix.api.gateway.model.engine_id_body import EngineIdBody
from delphix.api.gateway.model.engine_registration_parameter import EngineRegistrationParameter
from delphix.api.gateway.model.environment import Environment
from delphix.api.gateway.model.environment_create_parameters import EnvironmentCreateParameters
from delphix.api.gateway.model.environment_update_parameters import EnvironmentUpdateParameters
from delphix.api.gateway.model.environment_user import EnvironmentUser
from delphix.api.gateway.model.environment_user_params import EnvironmentUserParams
from delphix.api.gateway.model.error import Error
from delphix.api.gateway.model.error_response import ErrorResponse
from delphix.api.gateway.model.errors import Errors
from delphix.api.gateway.model.execute_masking_job_parameters import ExecuteMaskingJobParameters
from delphix.api.gateway.model.execute_masking_job_response import ExecuteMaskingJobResponse
from delphix.api.gateway.model.execution import Execution
from delphix.api.gateway.model.execution_cancel_parameters import ExecutionCancelParameters
from delphix.api.gateway.model.global_properties import GlobalProperties
from delphix.api.gateway.model.hashicorp_vault import HashicorpVault
from delphix.api.gateway.model.hook import Hook
from delphix.api.gateway.model.host import Host
from delphix.api.gateway.model.host_create_parameters import HostCreateParameters
from delphix.api.gateway.model.host_update_parameters import HostUpdateParameters
from delphix.api.gateway.model.job import Job
from delphix.api.gateway.model.ldap_config_params import LDAPConfigParams
from delphix.api.gateway.model.ldap_config_validate_parameter import LdapConfigValidateParameter
from delphix.api.gateway.model.ldap_validate_response import LdapValidateResponse
from delphix.api.gateway.model.list_access_groups_response import ListAccessGroupsResponse
from delphix.api.gateway.model.list_accounts_response import ListAccountsResponse
from delphix.api.gateway.model.list_bookmarks_by_vdb_groups_response import ListBookmarksByVDBGroupsResponse
from delphix.api.gateway.model.list_bookmarks_response import ListBookmarksResponse
from delphix.api.gateway.model.list_cdbs_response import ListCDBsResponse
from delphix.api.gateway.model.list_connectors_response import ListConnectorsResponse
from delphix.api.gateway.model.list_d_sources_response import ListDSourcesResponse
from delphix.api.gateway.model.list_database_templates_response import ListDatabaseTemplatesResponse
from delphix.api.gateway.model.list_environment_users import ListEnvironmentUsers
from delphix.api.gateway.model.list_environments_response import ListEnvironmentsResponse
from delphix.api.gateway.model.list_executions_response import ListExecutionsResponse
from delphix.api.gateway.model.list_hashicorp_vaults_response import ListHashicorpVaultsResponse
from delphix.api.gateway.model.list_jobs_response import ListJobsResponse
from delphix.api.gateway.model.list_masking_job_source_engines_response import ListMaskingJobSourceEnginesResponse
from delphix.api.gateway.model.list_masking_jobs_response import ListMaskingJobsResponse
from delphix.api.gateway.model.list_registered_engines_response import ListRegisteredEnginesResponse
from delphix.api.gateway.model.list_reporting_schedule_response import ListReportingScheduleResponse
from delphix.api.gateway.model.list_roles_response import ListRolesResponse
from delphix.api.gateway.model.list_snapshots_response import ListSnapshotsResponse
from delphix.api.gateway.model.list_sources_response import ListSourcesResponse
from delphix.api.gateway.model.list_vcdbs_response import ListVCDBsResponse
from delphix.api.gateway.model.list_vdb_groups_by_bookmark_response import ListVDBGroupsByBookmarkResponse
from delphix.api.gateway.model.list_vdb_groups_response import ListVDBGroupsResponse
from delphix.api.gateway.model.list_vdbs_response import ListVDBsResponse
from delphix.api.gateway.model.login_token import LoginToken
from delphix.api.gateway.model.masking_job import MaskingJob
from delphix.api.gateway.model.masking_job_connectors_response import MaskingJobConnectorsResponse
from delphix.api.gateway.model.masking_job_source_engine import MaskingJobSourceEngine
from delphix.api.gateway.model.masking_ruleset import MaskingRuleset
from delphix.api.gateway.model.migrate_masking_job_parameters import MigrateMaskingJobParameters
from delphix.api.gateway.model.migrate_masking_job_response import MigrateMaskingJobResponse
from delphix.api.gateway.model.object_permission_access_groups import ObjectPermissionAccessGroups
from delphix.api.gateway.model.object_permission_account import ObjectPermissionAccount
from delphix.api.gateway.model.object_permissions_response import ObjectPermissionsResponse
from delphix.api.gateway.model.object_type_enum import ObjectTypeEnum
from delphix.api.gateway.model.object_type_property import ObjectTypeProperty
from delphix.api.gateway.model.oracle_rac_custom_env_file import OracleRacCustomEnvFile
from delphix.api.gateway.model.oracle_rac_custom_env_var import OracleRacCustomEnvVar
from delphix.api.gateway.model.oracle_virtual_ip import OracleVirtualIP
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
from delphix.api.gateway.model.password_policies_params import PasswordPoliciesParams
from delphix.api.gateway.model.permission_enum import PermissionEnum
from delphix.api.gateway.model.permission_object import PermissionObject
from delphix.api.gateway.model.permission_property import PermissionProperty
from delphix.api.gateway.model.permissions_request import PermissionsRequest
from delphix.api.gateway.model.primary_environment_user_response import PrimaryEnvironmentUserResponse
from delphix.api.gateway.model.product_history import ProductHistory
from delphix.api.gateway.model.product_info import ProductInfo
from delphix.api.gateway.model.provision_vdbby_snapshot_defaults_request import ProvisionVDBBySnapshotDefaultsRequest
from delphix.api.gateway.model.provision_vdbby_snapshot_parameters import ProvisionVDBBySnapshotParameters
from delphix.api.gateway.model.provision_vdbby_snapshot_parameters_all_of import ProvisionVDBBySnapshotParametersAllOf
from delphix.api.gateway.model.provision_vdbby_timestamp_parameters import ProvisionVDBByTimestampParameters
from delphix.api.gateway.model.provision_vdbby_timestamp_parameters_all_of import ProvisionVDBByTimestampParametersAllOf
from delphix.api.gateway.model.provision_vdb_from_bookmark_defaults_request import ProvisionVDBFromBookmarkDefaultsRequest
from delphix.api.gateway.model.provision_vdb_from_bookmark_parameters import ProvisionVDBFromBookmarkParameters
from delphix.api.gateway.model.provision_vdb_from_bookmark_parameters_all_of import ProvisionVDBFromBookmarkParametersAllOf
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_parameters import ProvisionVDBGroupFromBookmarkParameters
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_response import ProvisionVDBGroupFromBookmarkResponse
from delphix.api.gateway.model.provision_vdb_response import ProvisionVDBResponse
from delphix.api.gateway.model.refresh_environment_response import RefreshEnvironmentResponse
from delphix.api.gateway.model.refresh_vdbby_snapshot_parameters import RefreshVDBBySnapshotParameters
from delphix.api.gateway.model.refresh_vdbby_snapshot_response import RefreshVDBBySnapshotResponse
from delphix.api.gateway.model.refresh_vdbby_timestamp_parameters import RefreshVDBByTimestampParameters
from delphix.api.gateway.model.refresh_vdbby_timestamp_parameters_all_of import RefreshVDBByTimestampParametersAllOf
from delphix.api.gateway.model.refresh_vdbby_timestamp_response import RefreshVDBByTimestampResponse
from delphix.api.gateway.model.refresh_vdb_from_bookmark_parameters import RefreshVDBFromBookmarkParameters
from delphix.api.gateway.model.refresh_vdb_from_bookmark_response import RefreshVDBFromBookmarkResponse
from delphix.api.gateway.model.refresh_vdb_group_parameters import RefreshVDBGroupParameters
from delphix.api.gateway.model.refresh_vdb_group_response import RefreshVDBGroupResponse
from delphix.api.gateway.model.registered_engine import RegisteredEngine
from delphix.api.gateway.model.remove_masking_job_parameters import RemoveMaskingJobParameters
from delphix.api.gateway.model.reporting_schedule import ReportingSchedule
from delphix.api.gateway.model.reporting_schedule_create_parameters import ReportingScheduleCreateParameters
from delphix.api.gateway.model.repository import Repository
from delphix.api.gateway.model.reset_password_parameter import ResetPasswordParameter
from delphix.api.gateway.model.role import Role
from delphix.api.gateway.model.role_all_of import RoleAllOf
from delphix.api.gateway.model.role_update_parameters import RoleUpdateParameters
from delphix.api.gateway.model.rollback_vdbby_snapshot_parameters import RollbackVDBBySnapshotParameters
from delphix.api.gateway.model.rollback_vdbby_snapshot_response import RollbackVDBBySnapshotResponse
from delphix.api.gateway.model.rollback_vdbby_timestamp_parameters import RollbackVDBByTimestampParameters
from delphix.api.gateway.model.rollback_vdbby_timestamp_response import RollbackVDBByTimestampResponse
from delphix.api.gateway.model.rollback_vdb_from_bookmark_parameters import RollbackVDBFromBookmarkParameters
from delphix.api.gateway.model.rollback_vdb_from_bookmark_response import RollbackVDBFromBookmarkResponse
from delphix.api.gateway.model.rollback_vdb_group_parameters import RollbackVDBGroupParameters
from delphix.api.gateway.model.rollback_vdb_group_response import RollbackVDBGroupResponse
from delphix.api.gateway.model.saml_config_params import SAMLConfigParams
from delphix.api.gateway.model.smtp_config_params import SMTPConfigParams
from delphix.api.gateway.model.smtp_config_validate import SMTPConfigValidate
from delphix.api.gateway.model.ssh_verification_strategy import SSHVerificationStrategy
from delphix.api.gateway.model.scope_tag import ScopeTag
from delphix.api.gateway.model.scope_tags_request import ScopeTagsRequest
from delphix.api.gateway.model.scope_tags_response import ScopeTagsResponse
from delphix.api.gateway.model.scoped_object_item import ScopedObjectItem
from delphix.api.gateway.model.scoped_object_items_response import ScopedObjectItemsResponse
from delphix.api.gateway.model.scoped_objects_request import ScopedObjectsRequest
from delphix.api.gateway.model.search_access_groups_response import SearchAccessGroupsResponse
from delphix.api.gateway.model.search_accounts_response import SearchAccountsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_bookmarks_response import SearchBookmarksResponse
from delphix.api.gateway.model.search_cdbs_response import SearchCDBsResponse
from delphix.api.gateway.model.search_connectors_response import SearchConnectorsResponse
from delphix.api.gateway.model.search_d_sources_response import SearchDSourcesResponse
from delphix.api.gateway.model.search_database_templates_response import SearchDatabaseTemplatesResponse
from delphix.api.gateway.model.search_engines_response import SearchEnginesResponse
from delphix.api.gateway.model.search_environments_response import SearchEnvironmentsResponse
from delphix.api.gateway.model.search_executions_response import SearchExecutionsResponse
from delphix.api.gateway.model.search_jobs_response import SearchJobsResponse
from delphix.api.gateway.model.search_masking_job_source_engines_response import SearchMaskingJobSourceEnginesResponse
from delphix.api.gateway.model.search_masking_jobs_response import SearchMaskingJobsResponse
from delphix.api.gateway.model.search_roles_response import SearchRolesResponse
from delphix.api.gateway.model.search_snapshots_response import SearchSnapshotsResponse
from delphix.api.gateway.model.search_sources_response import SearchSourcesResponse
from delphix.api.gateway.model.search_vcdbs_response import SearchVCDBsResponse
from delphix.api.gateway.model.search_vdb_group_response import SearchVDBGroupResponse
from delphix.api.gateway.model.search_vdbs_response import SearchVDBsResponse
from delphix.api.gateway.model.snapshot import Snapshot
from delphix.api.gateway.model.snapshot_d_source_response import SnapshotDSourceResponse
from delphix.api.gateway.model.snapshot_day_range import SnapshotDayRange
from delphix.api.gateway.model.snapshot_vdb_response import SnapshotVDBResponse
from delphix.api.gateway.model.snapshots_day_ranges_response import SnapshotsDayRangesResponse
from delphix.api.gateway.model.source import Source
from delphix.api.gateway.model.start_vdb_response import StartVDBResponse
from delphix.api.gateway.model.stop_vdb_response import StopVDBResponse
from delphix.api.gateway.model.tag import Tag
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.task_event import TaskEvent
from delphix.api.gateway.model.time_to_update_sources_request import TimeToUpdateSourcesRequest
from delphix.api.gateway.model.time_to_update_sources_response import TimeToUpdateSourcesResponse
from delphix.api.gateway.model.token_info_request import TokenInfoRequest
from delphix.api.gateway.model.token_info_response import TokenInfoResponse
from delphix.api.gateway.model.update_access_group_scope import UpdateAccessGroupScope
from delphix.api.gateway.model.update_connector_response import UpdateConnectorResponse
from delphix.api.gateway.model.update_database_template_parameters import UpdateDatabaseTemplateParameters
from delphix.api.gateway.model.update_database_template_response import UpdateDatabaseTemplateResponse
from delphix.api.gateway.model.update_environment_response import UpdateEnvironmentResponse
from delphix.api.gateway.model.update_environment_user_response import UpdateEnvironmentUserResponse
from delphix.api.gateway.model.update_host_response import UpdateHostResponse
from delphix.api.gateway.model.update_masking_job_parameters import UpdateMaskingJobParameters
from delphix.api.gateway.model.update_vdb_group_parameters import UpdateVDBGroupParameters
from delphix.api.gateway.model.update_vdb_parameters import UpdateVDBParameters
from delphix.api.gateway.model.update_vdb_response import UpdateVDBResponse
from delphix.api.gateway.model.vcdb import VCDB
from delphix.api.gateway.model.vdb import VDB
from delphix.api.gateway.model.vdb_group import VDBGroup
from delphix.api.gateway.model.vdb_inventory_data import VDBInventoryData
from delphix.api.gateway.model.vdb_inventory_report_response import VDBInventoryReportResponse
from delphix.api.gateway.model.virtual_dataset_hooks import VirtualDatasetHooks
from delphix.api.gateway.model.virtualization_storage_summary_data import VirtualizationStorageSummaryData
from delphix.api.gateway.model.virtualization_storage_summary_report_response import VirtualizationStorageSummaryReportResponse



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.cdbs_api import CDBsApi  # noqa: E501


class TestCDBsApi(unittest.TestCase):
    """CDBsApi unit test stubs"""

    def setUp(self):
        self.api = CDBsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cdb_tags(self):
        """Test case for create_cdb_tags

        Create tags for a CDB.  # noqa: E501
        """
        pass

    def test_delete_cdb_tags(self):
        """Test case for delete_cdb_tags

        Delete tags for a CDB.  # noqa: E501
        """
        pass

    def test_get_cdb_by_id(self):
        """Test case for get_cdb_by_id

        Get a CDB by ID (Oracle only).  # noqa: E501
        """
        pass

    def test_get_cdbs(self):
        """Test case for get_cdbs

        List all CDBs (Oracle only).  # noqa: E501
        """
        pass

    def test_get_tags_cdb(self):
        """Test case for get_tags_cdb

        Get tags for a CDB.  # noqa: E501
        """
        pass

    def test_search_cdbs(self):
        """Test case for search_cdbs

        Search for CDBs (Oracle only).  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.reporting_api import ReportingApi  # noqa: E501


class TestReportingApi(unittest.TestCase):
    """ReportingApi unit test stubs"""

    def setUp(self):
        self.api = ReportingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_reporting_schedule(self):
        """Test case for create_reporting_schedule

        Create a new report schedule.  # noqa: E501
        """
        pass

    def test_delete_reporting_schedule(self):
        """Test case for delete_reporting_schedule

        Delete report schedule by ID.  # noqa: E501
        """
        pass

    def test_get_api_usage_report(self):
        """Test case for get_api_usage_report

        Gets the report of API usage metrics over a given time period.  # noqa: E501
        """
        pass

    def test_get_dsource_consumption_report(self):
        """Test case for get_dsource_consumption_report

        Gets the consumption report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_get_dsource_usage_report(self):
        """Test case for get_dsource_usage_report

        Gets the usage report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_get_product_info(self):
        """Test case for get_product_info

        Returns the DCT Product Information.  # noqa: E501
        """
        pass

    def test_get_reporting_schedule_by_id(self):
        """Test case for get_reporting_schedule_by_id

        Returns a report schedule by ID.  # noqa: E501
        """
        pass

    def test_get_reporting_schedules(self):
        """Test case for get_reporting_schedules

        List all report schedules.  # noqa: E501
        """
        pass

    def test_get_vdb_inventory_report(self):
        """Test case for get_vdb_inventory_report

        Gets the inventory report for virtualization engine VDBs.  # noqa: E501
        """
        pass

    def test_get_virtualization_storage_summary_report(self):
        """Test case for get_virtualization_storage_summary_report

        Gets the storage summary report for virtualization engines.  # noqa: E501
        """
        pass

    def test_search_dsource_consumption_report(self):
        """Test case for search_dsource_consumption_report

        Search the consumption report for virtualization engine DSources.  # noqa: E501
        """
        pass

    def test_search_dsource_usage_report(self):
        """Test case for search_dsource_usage_report

        Search the usage report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_search_vdb_inventory_report(self):
        """Test case for search_vdb_inventory_report

        Search the inventory report for virtualization engine VDBs.  # noqa: E501
        """
        pass

    def test_search_virtualization_storage_summary_report(self):
        """Test case for search_virtualization_storage_summary_report

        Search the storage summary report for virtualization engines.  # noqa: E501
        """
        pass

    def test_update_reporting_schedule(self):
        """Test case for update_reporting_schedule

        Update a reporting schedule by ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.d_sources_api import DSourcesApi  # noqa: E501


class TestDSourcesApi(unittest.TestCase):
    """DSourcesApi unit test stubs"""

    def setUp(self):
        self.api = DSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tags_dsource(self):
        """Test case for create_tags_dsource

        Create tags for a dSource.  # noqa: E501
        """
        pass

    def test_delete_tags_dsource(self):
        """Test case for delete_tags_dsource

        Delete tags for a dSource.  # noqa: E501
        """
        pass

    def test_get_dsource_by_id(self):
        """Test case for get_dsource_by_id

        Get a dSource by ID.  # noqa: E501
        """
        pass

    def test_get_dsource_snapshots(self):
        """Test case for get_dsource_snapshots

        List Snapshots for a dSource.  # noqa: E501
        """
        pass

    def test_get_dsources(self):
        """Test case for get_dsources

        List all dSources.  # noqa: E501
        """
        pass

    def test_get_tags_dsource(self):
        """Test case for get_tags_dsource

        Get tags for a dSource.  # noqa: E501
        """
        pass

    def test_search_dsources(self):
        """Test case for search_dsources

        Search for DSources.  # noqa: E501
        """
        pass

    def test_snapshot_dsource(self):
        """Test case for snapshot_dsource

        Snapshot a DSource.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.snapshots_api import SnapshotsApi  # noqa: E501


class TestSnapshotsApi(unittest.TestCase):
    """SnapshotsApi unit test stubs"""

    def setUp(self):
        self.api = SnapshotsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_snapshot_by_id(self):
        """Test case for get_snapshot_by_id

        Get a Snapshot by ID.  # noqa: E501
        """
        pass

    def test_get_snapshots(self):
        """Test case for get_snapshots

        Retrieve the list of snapshots.  # noqa: E501
        """
        pass

    def test_get_snapshots_day_ranges(self):
        """Test case for get_snapshots_day_ranges

        Returns the count of TimeFlow snapshots of the timeflow aggregated by day. The time zone \\ used to perform the computation is the time zone of the last snapshot of the timeflow.   # noqa: E501
        """
        pass

    def test_search_snapshots(self):
        """Test case for search_snapshots

        Search snapshots.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
